@@ -27,16 +27,24 @@ class WpSocketClient:
         self._receive_packet_queue: asyncio.Queue[bytes] = asyncio.Queue()
         self._send_packet_queue: asyncio.Queue[bytes] = asyncio.Queue()
 
-        self._connected = False
         self._retry_cnt = 0
+        self.connected = False
 
     async def async_on_connected(self):
         """Socket connected notifications"""
-        _LOGGER.debug('connected %s', self._host)
+        pass
+
+    async def async_on_disconnected(self):
+        """Socket disconnected notifications"""
+        pass
+
+    async def async_on_reconnect(self):
+        """Socket reconnect notifications"""
+        pass
 
     async def async_connect(self) -> bool:
         """Socket connect"""
-        await self.async_wait_for_disconnect()
+        await self._async_wait_for_disconnect()
 
         _LOGGER.debug('connecting to server %s', self._host)
         try:
@@ -44,7 +52,7 @@ class WpSocketClient:
             self._reader, self._writer = await asyncio.wait_for(
                 asyncio.open_connection(self._host, self._port),
                 timeout=_CONNECTION_TIMEOUT)
-            self._connected = True
+            self.connected = True
             self._retry_cnt = 0
 
             self._loop.create_task(self.async_on_connected())
@@ -61,6 +69,7 @@ class WpSocketClient:
 
     async def _async_reconnect(self):
         """Socket reconnect"""
+        self._loop.create_task(self.async_on_reconnect())
         wait_time = self._retry_cnt * 5 if self._retry_cnt < 12 else 60
         _LOGGER.debug('reconnect connect, wait %d s', wait_time)
         await asyncio.sleep(wait_time)
@@ -75,7 +84,7 @@ class WpSocketClient:
     async def _async_reader_handler(self):
         """Queue read handler"""
         _LOGGER.debug('message handler start')
-        while self._connected:
+        while self.connected:
             try:
                 packets = await asyncio.wait_for(self._receive_packet_queue.get(),
                                                  timeout=_QUEUE_WAIT_TIMEOUT)
@@ -91,7 +100,7 @@ class WpSocketClient:
     async def _async_reader(self):
         """Socket read packet"""
         _LOGGER.debug('reader start')
-        while self._connected:
+        while self.connected:
             try:
                 data = await asyncio.wait_for(self._reader.read(_DEFAULT_READ_BUFFER),
                                               timeout=_READ_TIMEOUT)
@@ -110,7 +119,7 @@ class WpSocketClient:
     async def _async_writer(self):
         """Socket write packet"""
         _LOGGER.debug('writer start')
-        while self._connected:
+        while self.connected:
             try:
                 packet = await asyncio.wait_for(self._send_packet_queue.get(),
                                                 timeout=_QUEUE_WAIT_TIMEOUT)
@@ -126,7 +135,7 @@ class WpSocketClient:
                 break
         _LOGGER.debug('writer end')
 
-    async def async_wait_for_disconnect(self):
+    async def _async_wait_for_disconnect(self):
         """disconnect and task exit wait"""
         self.disconnect()
         if self._wait_tasks is None:
@@ -136,11 +145,12 @@ class WpSocketClient:
 
     def disconnect(self):
         """disconnect"""
-        if not self._connected:
+        if not self.connected:
             return
-        self._connected = False
+        self.connected = False
         if not self._loop.is_closed():
             self._writer.close()
+        self._loop.create_task(self.async_on_disconnected())
 
     def __del__(self):
         self.disconnect()
